# Example Package

This is a simple example package. You can use
[GitHub-flavored Markdown](https://guides.github.com/features/mastering-markdown/)

# Task Manager 
Simple application for task management using Python, based on the example of a hotel booking manager.

## Prerequisites 
- Python 3.8 o superior  

